@@ -24,6 +24,9 @@
 
 #include <string.h>
 #include <gtk/gtk.h>
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>
+#endif
 #include <libxfce4ui/libxfce4ui.h>
 
 #include "wck-plugin.h"
@@ -51,14 +54,97 @@ wck_properties_get_channel (GObject *object_for_weak_ref, const gchar *channel_n
 }
 
 
+WckConf *
+wck_conf_new (XfcePanelPlugin *plugin)
+{
+    WckConf *conf = g_slice_new0 (WckConf);
+
+    conf->channel = wck_properties_get_channel (G_OBJECT (plugin), "xfce4-panel");
+    conf->property_base = xfce_panel_plugin_get_property_base (plugin);
+
+    return conf;
+}
+
+
+gboolean
+wck_conf_get_bool (const WckConf *conf, const gchar *setting, gboolean default_value)
+{
+    gchar    *property;
+    gboolean  value;
+
+    property = g_strconcat (conf->property_base, setting, NULL);
+    value = xfconf_channel_get_bool (conf->channel, property, default_value);
+    g_free (property);
+
+    return value;
+}
+
+
+gint
+wck_conf_get_int (const WckConf *conf, const gchar *setting, gint default_value)
+{
+    gchar *property;
+    gint   value;
+
+    property = g_strconcat (conf->property_base, setting, NULL);
+    value = xfconf_channel_get_int (conf->channel, property, default_value);
+    g_free (property);
+
+    return value;
+}
+
+
+gchar *
+wck_conf_get_string (const WckConf *conf, const gchar *setting, const gchar *default_value)
+{
+    gchar *property;
+    gchar *value;
+
+    property = g_strconcat (conf->property_base, setting, NULL);
+    value = xfconf_channel_get_string (conf->channel, property, default_value);
+    g_free (property);
+
+    return value;
+}
+
+
+void
+wck_conf_set_bool (const WckConf *conf, const gchar *setting, gboolean value)
+{
+    gchar *property;
+
+    property = g_strconcat (conf->property_base, setting, NULL);
+    xfconf_channel_set_bool (conf->channel, property, value);
+    g_free (property);
+}
+
+
+void
+wck_conf_set_int (const WckConf *conf, const gchar *setting, gint value)
+{
+    gchar *property;
+
+    property = g_strconcat (conf->property_base, setting, NULL);
+    xfconf_channel_set_int (conf->channel, property, value);
+    g_free (property);
+}
+
+
+void
+wck_conf_set_string (const WckConf *conf, const gchar *setting, const gchar *value)
+{
+    gchar *property;
+
+    property = g_strconcat (conf->property_base, setting, NULL);
+    xfconf_channel_set_string (conf->channel, property, value);
+    g_free (property);
+}
+
+
 void
 wck_about (XfcePanelPlugin *plugin, const gchar *icon_name)
 {
-    /* about dialog code. you can use the GtkAboutDialog
-    * or the XfceAboutInfo widget */
-    GdkPixbuf *icon;
-
-    const gchar *auth[] =
+    const gchar *authors[] =
     {
         "Alessio Piccoli <alepic@geckoblu.net>",
         "Cedric Leporcq <cedl38@gmail.com>",
@@ -70,33 +156,24 @@ wck_about (XfcePanelPlugin *plugin, const gchar *icon_name)
         NULL
     };
 
-    icon = xfce_panel_pixbuf_from_source(icon_name, NULL, 32);
-
+    /* TODO: add translators. */
     gtk_show_about_dialog (NULL,
-            "logo", icon,
-            "license", xfce_get_license_text(XFCE_LICENSE_TEXT_GPL),
-            "version", PACKAGE_VERSION,
-            "program-name", xfce_panel_plugin_get_display_name (plugin),
-            "comments", xfce_panel_plugin_get_comment (plugin),
-            "website", PACKAGE_URL,
-            "copyright", "Copyright \302\251 2013-2015\n",
-            "authors", auth,
-            NULL );
-    // TODO: add translators.
-
-    if (icon)
-        g_object_unref(G_OBJECT(icon) );
+                           "logo-icon-name", icon_name,
+                           "license", xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
+                           "version", PACKAGE_VERSION,
+                           "program-name", xfce_panel_plugin_get_display_name (plugin),
+                           "comments", xfce_panel_plugin_get_comment (plugin),
+                           "website", PACKAGE_URL,
+                           "copyright", "Copyright \302\251 2003-2024 The Xfce development team",
+                           "authors", authors,
+                           NULL);
 }
 
 
 GtkWidget *show_refresh_item (XfcePanelPlugin *plugin)
 {
     GtkWidget *refresh;
-#if LIBXFCE4UI_CHECK_VERSION (4, 16, 0)
     refresh = xfce_gtk_image_menu_item_new_from_icon_name (_("_Refresh"), NULL, NULL, NULL, NULL, "view-refresh", NULL);
-#else
-    refresh = gtk_image_menu_item_new_from_stock (GTK_STOCK_REFRESH, NULL);
-#endif
     xfce_panel_plugin_menu_insert_item(plugin, GTK_MENU_ITEM(refresh));
     gtk_widget_show (refresh);
 
@@ -104,70 +181,6 @@ GtkWidget *show_refresh_item (XfcePanelPlugin *plugin)
 }
 
 
-void
-wck_settings_save (XfcePanelPlugin *plugin, WckSettingsCb save_settings, gpointer prefs)
-{
-    XfceRc *rc;
-    gchar *file;
-
-    /* get the config file location */
-    file = xfce_panel_plugin_save_location (plugin, TRUE);
-
-    if (G_UNLIKELY (file == NULL))
-    {
-        DBG ("Failed to open config file");
-        return;
-    }
-
-    /* open the config file, read/write */
-    rc = xfce_rc_simple_open (file, FALSE);
-    g_free (file);
-
-    if (G_LIKELY (rc != NULL))
-    {
-        /* save the settings */
-        DBG (".");
-        save_settings (rc, prefs);
-
-        /* close the rc file */
-        xfce_rc_close (rc);
-    }
-}
-
-
-void
-wck_settings_load (XfcePanelPlugin *plugin, WckSettingsCb load_settings, gpointer prefs)
-{
-    /* get the plugin config file location */
-    gchar *file = xfce_panel_plugin_save_location (plugin, TRUE);
-
-    if (G_LIKELY (file != NULL))
-    {
-        /* open the config file, readonly */
-        XfceRc *rc = xfce_rc_simple_open (file, TRUE);
-
-        /* cleanup */
-        g_free (file);
-
-        if (G_LIKELY (rc != NULL))
-        {
-            /* read the settings */
-            load_settings (rc, prefs);
-
-            /* cleanup */
-            xfce_rc_close (rc);
-
-            /* leave the function, everything went well */
-            return;
-        }
-    }
-
-    /* something went wrong, apply default values */
-    DBG ("Applying default settings");
-    load_settings (NULL, prefs);
-}
-
-
 GtkWidget *
 wck_dialog_get_widget (GtkBuilder *builder, const gchar *name)
 {
@@ -245,9 +258,32 @@ wck_configure_response (XfcePanelPlugin *plugin, GtkWidget *dialog, gint respons
         xfce_panel_plugin_unblock_menu (plugin);
 
         /* save the plugin */
-        wck_settings_save (plugin, save_settings, data);
+        save_settings (data);
 
         /* destroy the properties dialog */
         gtk_widget_destroy (dialog);
     }
 }
+
+
+gboolean
+wck_abort_non_x11_windowing (XfcePanelPlugin *plugin)
+{
+#ifdef GDK_WINDOWING_X11
+    gboolean x11_windowing = GDK_IS_X11_DISPLAY (gdk_display_get_default ());
+#else
+    gboolean x11_windowing = FALSE;
+#endif
+    if (!x11_windowing)
+    {
+        GtkWidget *dialog = xfce_message_dialog_new (NULL, xfce_panel_plugin_get_display_name (plugin), "dialog-error",
+                                                     _("Unsupported windowing environment"), NULL,
+                                                     _("_OK"), GTK_RESPONSE_OK, NULL);
+        gtk_dialog_run (GTK_DIALOG (dialog));
+        gtk_widget_destroy (dialog);
+        xfce_panel_plugin_remove (plugin);
+        return TRUE;
+    }
+
+    return FALSE;
+}
